A Jupyter/IPython kernel for Octave

This requires IPython 3, and Octave installed with gnuplot support.

Install as ``pip install octave_kernel``.

Then, you can select the "Octave" Kernel in the IPython Notebook.

This is based on `MetaKernel <http://pypi.python.org/pypi/metakernel>`_,
which means it features a standard set of magics.

A sample notebook is available online_.

You can specify the path to `octave` by setting the OCTAVE_EXECUTABLE 
environment variable.

.. _online: http://nbviewer.ipython.org/github/Calysto/octave_kernel/blob/master/octave_kernel.ipynb
